Port of TI's CC3100 Websock camera demo. Using FreeRTOS, mbedTLS, also parts of Arducam for cams ov5642 and 0v2640. Can also use MT9D111. Work in progress. Be warned some parts maybe a bit flacky. This is for Seeed Arch max only, for an M3, see the demo for CM3 using the 0v5642 aducam mini.

Dependencies:   mbed

Revision:
1:1a80c1529aa3
Parent:
0:50cedd586816
Child:
2:b92db44a29b4
--- a/main.cpp	Wed Jun 24 09:54:16 2015 +0000
+++ b/main.cpp	Thu Jun 25 18:37:49 2015 +0000
@@ -120,8 +120,10 @@
   RCC_ClkInitStruct.APB2CLKDivider = RCC_HCLK_DIV2;
   HAL_RCC_ClockConfig(&RCC_ClkInitStruct, FLASH_LATENCY_5);
   
-  /* 42MHz mco output on pin PC_9 (cam xclk) */
-  HAL_RCC_MCOConfig(RCC_MCO2, RCC_MCO2SOURCE_SYSCLK, RCC_MCODIV_4);
+  /* RCC_MCODIV_5 33.6MHz mco output on pin PC_9 (cam xclk) */
+  /* RCC_MCODIV_4 42MHz mco output on pin PC_9 (cam xclk) */
+  /* RCC_MCODIV_3 56MHz mco output on pin PC_9 (cam xclk) */
+  HAL_RCC_MCOConfig(RCC_MCO2, RCC_MCO2SOURCE_SYSCLK, RCC_MCODIV_3);
 
   HAL_SYSTICK_Config(HAL_RCC_GetHCLKFreq()/1000);
 
@@ -162,7 +164,7 @@
 
 }
 
-/* Warning if pin chages are made below then the same changes have to be made in the following files.
+/* Warning if pin changes are made below then the same changes have to be made in the following files.
  * httpserverapp.cpp
  * HttpCore.cpp
  * HttpSocket.cpp